# ESDaP

[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-v2.0%20adopted-ff69b4.svg)](code_of_conduct.md)

A Python package for **E**pileptic **S**eizure **D**etection **a**nd **P**rediction from EEG data.

**Authors**: [Fabian Egli](https://github.com/fabianegli/), [Nick Pullen](https://github.com/nstjhp/), [Alessandro Quercia](https://github.com/AlessioQuercia/), [Thomas Frick](https://github.com/thomfrick/), [Isabelle Dupanloup](https://github.com/idupanloup/)

**License**: GNU General Public License Version 3 or any later version


# Installation

We support conda and pip.

To ensure a consistent environment we provide two files for easy Anaconda environment setups. `conda_env.yaml` sets up an environment for the use of the code
and `conda_dev_env.yaml` additionally installs development tools.

# Usage

We use bash scripts to run the python package. 
Example bash scripts can be found in the [official repository's](https://github.com/idupanloup/ESDaP) `examples` folder.

# Contributing

Please note that this project is released with a Contributor Code of Conduct. By participating in this project you agree to abide by its terms.

